@@ -1,18 +1,24 @@
 module Fog
   module Compute
     class Cloudstack
+
       class Real
-
-        def query_async_job_result(options={})
-          options.merge!(
-            'command' => 'queryAsyncJobResult'
-          )
-
+        # Retrieves the current status of asynchronous job.
+        #
+        # {CloudStack API Reference}[http://cloudstack.apache.org/docs/api/apidocs-4.4/root_admin/queryAsyncJobResult.html]
+        def query_async_job_result(*args)
+          options = {}
+          if args[0].is_a? Hash
+            options = args[0]
+            options.merge!('command' => 'queryAsyncJobResult') 
+          else
+            options.merge!('command' => 'queryAsyncJobResult', 
+            'jobid' => args[0])
+          end
           request(options)
         end
-
-      end # Real
-
+      end
+ 
       class Mock
         def query_async_job_result(options={})
           unless job_id = options['jobid']
@@ -25,8 +31,8 @@ module Fog
 
           {'queryasyncjobresultresponse' => job }
         end
-      end
-
+      end 
     end
   end
 end
+
