@@ -6,3 +6,5 @@ require 'fog/openstack/network'
 require 'fog/openstack/orchestration'
 require 'fog/openstack/storage'
 require 'fog/openstack/volume'
+require 'fog/openstack/baremetal'
+require 'fog/openstack/planning'
