@@ -3,9 +3,7 @@ require 'fog/core/model'
 module Fog
   module Compute
     class OpenStack
-
       class KeyPair < Fog::Model
-
         identity  :name
 
         attribute :fingerprint
@@ -37,7 +35,6 @@ module Fog
         end
 
         def write(path="#{ENV['HOME']}/.ssh/fog_#{Fog.credential.to_s}_#{name}.pem")
-
           if writable?
             split_private_key = private_key.split(/\n/)
             File.open(path, "w") do |f|
@@ -51,9 +48,8 @@ module Fog
         end
 
         def writable?
-          !!(private_key && ENV.has_key?('HOME'))
+          !!(private_key && ENV.key?('HOME'))
         end
-
       end
     end
   end
