@@ -5,7 +5,6 @@ module Fog
   module Network
     class OpenStack
       class SecurityGroupRules < Fog::Collection
-
         attribute :filters
 
         model Fog::Network::OpenStack::SecurityGroupRule
@@ -15,8 +14,8 @@ module Fog
           super
         end
 
-        def all(filters = filters)
-          self.filters = filters
+        def all(filters_arg = filters)
+          filters = filters_arg
           load(service.list_security_group_rules(filters).body['security_group_rules'])
         end
 
