@@ -4,14 +4,14 @@ require 'fog/openstack/models/storage/files'
 module Fog
   module Storage
     class OpenStack
-
       class Directory < Fog::Model
-
         identity  :key, :aliases => 'name'
 
         attribute :bytes, :aliases => 'X-Container-Bytes-Used'
         attribute :count, :aliases => 'X-Container-Object-Count'
 
+        attr_writer :public
+
         def destroy
           requires :key
           service.delete_container(key)
@@ -29,22 +29,22 @@ module Fog
           end
         end
 
-        def public=(new_public)
-          @public = new_public
-        end
-
         def public_url
-          raise NotImplementedError
+          requires :key
+
+          @public_url ||= begin
+            service.public_url(key)
+          rescue Fog::Storage::OpenStack::NotFound => err
+            nil
+          end
         end
 
         def save
           requires :key
-          service.put_container(key)
+          service.put_container(key, :public => @public)
           true
         end
-
       end
-
     end
   end
 end
