@@ -3,17 +3,16 @@ require 'fog/core/model'
 module Fog
   module Storage
     class OpenStack
-
       class File < Fog::Model
-
         identity  :key,             :aliases => 'name'
 
+        attribute :access_control_allow_origin, :aliases => ['Access-Control-Allow-Origin']
         attribute :content_length,  :aliases => ['bytes', 'Content-Length'], :type => :integer
         attribute :content_type,    :aliases => ['content_type', 'Content-Type']
         attribute :content_disposition, :aliases => ['content_disposition', 'Content-Disposition']
         attribute :etag,            :aliases => ['hash', 'Etag']
         attribute :last_modified,   :aliases => ['last_modified', 'Last-Modified'], :type => :time
-        attribute :access_control_allow_origin, :aliases => ['Access-Control-Allow-Origin']
+        attribute :metadata
         attribute :origin,          :aliases => ['Origin']
 
         def body
@@ -49,7 +48,7 @@ module Fog
         end
 
         def metadata
-          @metadata ||= headers_to_metadata
+          attributes[:metadata] ||= headers_to_metadata
         end
 
         def owner=(new_owner)
@@ -83,7 +82,6 @@ module Fog
           self.collection.get_url(self.key)
         end
 
-
         def save(options = {})
           requires :body, :directory, :key
           options['Content-Type'] = content_type if content_type
@@ -160,7 +158,6 @@ module Fog
           merge_attributes(data.headers.reject {|key, value| ['Content-Length', 'Content-Type'].include?(key)})
         end
       end
-
     end
   end
 end
