@@ -1,14 +1,13 @@
 module Fog
   module Network
     class OpenStack
-
       class Real
         def update_port(port_id, options = {})
           data = { 'port' => {} }
 
           vanilla_options = [:name, :fixed_ips, :admin_state_up, :device_owner,
                              :device_id]
-          vanilla_options.select{ |o| options.has_key?(o) }.each do |key|
+          vanilla_options.select{ |o| options.key?(o) }.each do |key|
             data['port'][key] = options[key]
           end
 
@@ -24,7 +23,7 @@ module Fog
       class Mock
         def update_port(port_id, options = {})
           response = Excon::Response.new
-          if port = list_ports.body['ports'].detect { |_| _['id'] == port_id }
+          if port = list_ports.body['ports'].find { |_| _['id'] == port_id }
             port['name']           = options[:name]
             port['fixed_ips']      = options[:fixed_ips]
             port['admin_state_up'] = options[:admin_state_up]
@@ -38,7 +37,6 @@ module Fog
           end
         end
       end
-
     end
   end
 end
