@@ -1,15 +1,14 @@
 module Fog
   module Storage
     class Rackspace
-
       module Common
-
         # Get an expiring object https url from Cloud Files
         #
         # ==== Parameters
         # * container<~String> - Name of container containing object
         # * object<~String> - Name of object to get expiring url for
         # * expires<~Time> - An expiry time for this url
+        # * options<~Hash> - Options to override the method or scheme
         #
         # ==== Returns
         # * response<~Excon::Response>:
@@ -22,10 +21,10 @@ module Fog
         # http://docs.rackspace.com/files/api/v1/cf-devguide/content/Create_TempURL-d1a444.html
         def get_object_https_url(container, object, expires, options = {})
           if @rackspace_temp_url_key.nil?
-            raise ArgumentError, "Storage must my instantiated with the :rackspace_temp_url_key option"
+            raise ArgumentError, "Storage must be instantiated with the :rackspace_temp_url_key option"
           end
 
-          method         = 'GET'
+          method         = options[:method] || 'GET'
           expires        = expires.to_i
           object_path_escaped   = "#{@uri.path}/#{Fog::Rackspace.escape(container)}/#{Fog::Rackspace.escape(object,"/")}"
           object_path_unescaped = "#{@uri.path}/#{Fog::Rackspace.escape(container)}/#{object}"
@@ -56,7 +55,6 @@ module Fog
       class Real
         include Common
       end
-
     end
   end
 end
