@@ -13,7 +13,7 @@ module Fog
         def get_raw_resource_pool(name, cluster_name, datacenter_name)
           dc      = find_raw_datacenter(datacenter_name)
           cluster = dc.find_compute_resource(cluster_name)
-          cluster.resourcePool.find name
+          name.nil? ? cluster.resourcePool : cluster.resourcePool.find( name)
         end
       end
 
