@@ -1,13 +1,13 @@
 module Fog
   module Compute
     class Vsphere
-
       module Shared
         private
         def vm_clone_check_options(options)
           default_options = {
             'force'        => false,
             'linked_clone' => false,
+            'nic_type' => 'VirtualE1000',
           }
           options = default_options.merge(options)
           # Backwards compat for "path" option
@@ -15,7 +15,7 @@ module Fog
           options["path"] ||= options["template_path"]
           required_options = %w{ datacenter template_path name }
           required_options.each do |param|
-            raise ArgumentError, "#{required_options.join(', ')} are required" unless options.has_key? param
+            raise ArgumentError, "#{required_options.join(', ')} are required" unless options.key? param
           end
           raise Fog::Compute::Vsphere::NotFound, "Datacenter #{options["datacenter"]} Doesn't Exist!" unless get_datacenter(options["datacenter"])
           raise Fog::Compute::Vsphere::NotFound, "Template #{options["template_path"]} Doesn't Exist!" unless get_virtual_machine(options["template_path"], options["datacenter"])
@@ -75,9 +75,6 @@ module Fog
           # Added for people still using options['path']
           template_path = options['path'] || options['template_path']
 
-          # Default wait enabled
-          options['wait'] = true
-
           # Options['template_path']<~String>
           # Added for people still using options['path']
           template_path = options['path'] || options['template_path']
@@ -86,12 +83,12 @@ module Fog
 
           # Options['dest_folder']<~String>
           # Grab the destination folder object if it exists else use cloned mach
-          dest_folder = get_raw_vmfolder(options['dest_folder'], options['datacenter']) if options.has_key?('dest_folder')
-          dest_folder ||= vm_mob_ref.parent
+          dest_folder_path = options.fetch('dest_folder','/') # default to root path ({dc_name}/vm/)
+          dest_folder = get_raw_vmfolder(dest_folder_path, options['datacenter'])
 
           # Options['resource_pool']<~Array>
           # Now find _a_ resource pool to use for the clone if one is not specified
-          if ( options.has_key?('resource_pool') && options['resource_pool'].is_a?(Array) && options['resource_pool'].length == 2 )
+          if ( options.key?('resource_pool') && options['resource_pool'].is_a?(Array) && options['resource_pool'].length == 2 )
             cluster_name = options['resource_pool'][0]
             pool_name = options['resource_pool'][1]
             resource_pool = get_raw_resource_pool(pool_name, cluster_name, options['datacenter'])
@@ -111,28 +108,38 @@ module Fog
 
           # Options['datastore']<~String>
           # Grab the datastore object if option is set
-          datastore_obj = get_raw_datastore(options['datastore'], options['datacenter']) if options.has_key?('datastore')
+          datastore_obj = get_raw_datastore(options['datastore'], options['datacenter']) if options.key?('datastore')
           # confirm nil if nil or option is not set
           datastore_obj ||= nil
           virtual_machine_config_spec = RbVmomi::VIM::VirtualMachineConfigSpec()
 
           # Options['network']
           # Build up the config spec
-          if ( options.has_key?('network_label') )
-            #network_obj = datacenter_obj.networkFolder.find(options['network_label'])
+          if ( options.key?('network_label') )
             config_spec_operation = RbVmomi::VIM::VirtualDeviceConfigSpecOperation('edit')
-            nic_backing_info = RbVmomi::VIM::VirtualEthernetCardNetworkBackingInfo(:deviceName => options['network_label'])
-              #:deviceName => "Network adapter 1",
-              #:network => network_obj)
+            # Get the portgroup and handle it from there.
+            network = get_raw_network(options['network_label'],options['datacenter'])
+            if ( network.kind_of? RbVmomi::VIM::DistributedVirtualPortgroup)
+                # Create the NIC backing for the distributed virtual portgroup
+                nic_backing_info = RbVmomi::VIM::VirtualEthernetCardDistributedVirtualPortBackingInfo(
+                    :port => RbVmomi::VIM::DistributedVirtualSwitchPortConnection( 
+                                                                                  :portgroupKey => network.key, 
+                                                                                  :switchUuid => network.config.distributedVirtualSwitch.uuid
+                                                                                 ) 
+                )
+            else
+                # Otherwise it's a non distributed port group
+                nic_backing_info = RbVmomi::VIM::VirtualEthernetCardNetworkBackingInfo(:deviceName => options['network_label'])
+            end
             connectable = RbVmomi::VIM::VirtualDeviceConnectInfo(
               :allowGuestControl => true,
               :connected => true,
               :startConnected => true)
-            device = RbVmomi::VIM::VirtualE1000(
+            device = RbVmomi::VIM.public_send "#{options['nic_type']}",
               :backing => nic_backing_info,
               :deviceInfo => RbVmomi::VIM::Description(:label => "Network adapter 1", :summary => options['network_label']),
               :key => options['network_adapter_device_key'],
-              :connectable => connectable)
+              :connectable => connectable
             device_spec = RbVmomi::VIM::VirtualDeviceConfigSpec(
               :operation => config_spec_operation,
               :device => device)
@@ -143,34 +150,41 @@ module Fog
           # https://github.com/rlane/rbvmomi/blob/master/test/test_serialization.rb
           # http://www.vmware.com/support/developer/vc-sdk/visdk41pubs/ApiReference/vim.vm.ConfigSpec.html
           # FIXME: pad this out with the rest of the useful things in VirtualMachineConfigSpec
-          virtual_machine_config_spec.numCPUs = options['numCPUs'] if  ( options.has_key?('numCPUs') )
-          virtual_machine_config_spec.memoryMB = options['memoryMB'] if ( options.has_key?('memoryMB') )
+          virtual_machine_config_spec.numCPUs = options['numCPUs'] if  ( options.key?('numCPUs') )
+          virtual_machine_config_spec.memoryMB = options['memoryMB'] if ( options.key?('memoryMB') )
+          virtual_machine_config_spec.cpuHotAddEnabled = options['cpuHotAddEnabled'] if ( options.key?('cpuHotAddEnabled') )
+          virtual_machine_config_spec.memoryHotAddEnabled = options['memoryHotAddEnabled'] if ( options.key?('memoryHotAddEnabled') )
+          virtual_machine_config_spec.firmware = options['firmware'] if ( options.key?('firmware') )
           # Options['customization_spec']
           # Build up all the crappy tiered objects like the perl method
           # Collect your variables ifset (writing at 11pm revist me)
           # * domain <~String> - *REQUIRED* - Sets the server's domain for customization
+          # * dnsSuffixList <~Array> - Optional - Sets the dns search paths in resolv - Example: ["dev.example.com", "example.com"]
           # * ipsettings <~Hash> - Optional - If not set defaults to dhcp
           #  * ip <~String> - *REQUIRED* Sets the ip address of the VM - Example: 10.0.0.10
           #  * dnsServerList <~Array> - Optional - Sets the nameservers in resolv - Example: ["10.0.0.2", "10.0.0.3"]
           #  * gateway <~Array> - Optional - Sets the gateway for the interface - Example: ["10.0.0.1"]
           #  * subnetMask <~String> - *REQUIRED* - Set the netmask of the interface - Example: "255.255.255.0"
           #    For other ip settings options see http://www.vmware.com/support/developer/vc-sdk/visdk41pubs/ApiReference/vim.vm.customization.IPSettings.html
-          if ( options.has_key?('customization_spec') )
+          if ( options.key?('customization_spec') )
             cust_options = options['customization_spec']
-            if cust_options.has_key?("ipsettings")
-              raise ArgumentError, "ip and subnetMask is required for static ip" unless cust_options["ipsettings"].has_key?("ip") and
-                                                                                        cust_options["ipsettings"].has_key?("subnetMask")
+            if cust_options.key?("ipsettings")
+              raise ArgumentError, "ip and subnetMask is required for static ip" unless cust_options["ipsettings"].key?("ip") and
+                                                                                        cust_options["ipsettings"].key?("subnetMask")
             end
-            raise ArgumentError, "domain is required" unless cust_options.has_key?("domain")
+            raise ArgumentError, "domain is required" unless cust_options.key?("domain")
             cust_domain = cust_options['domain']
-            cust_ip_settings = RbVmomi::VIM::CustomizationIPSettings.new(cust_options["ipsettings"]) if cust_options.has_key?("ipsettings")
-            cust_ip_settings.ip = RbVmomi::VIM::CustomizationFixedIp("ipAddress" => cust_options["ipsettings"]["ip"]) if cust_options.has_key?("ipsettings")
+            if cust_options.key?("ipsettings")
+              cust_ip_settings = RbVmomi::VIM::CustomizationIPSettings.new(cust_options["ipsettings"])
+              cust_ip_settings.ip = RbVmomi::VIM::CustomizationFixedIp("ipAddress" => cust_options["ipsettings"]["ip"])
+              cust_ip_settings.gateway = cust_options['ipsettings']['gateway']
+            end
             cust_ip_settings ||= RbVmomi::VIM::CustomizationIPSettings.new("ip" => RbVmomi::VIM::CustomizationDhcpIpGenerator.new())
             cust_ip_settings.dnsDomain = cust_domain
             cust_global_ip_settings = RbVmomi::VIM::CustomizationGlobalIPSettings.new
             cust_global_ip_settings.dnsServerList = cust_ip_settings.dnsServerList
-            cust_global_ip_settings.dnsSuffixList = [cust_domain]
-            cust_hostname = RbVmomi::VIM::CustomizationFixedName.new(:name => cust_options['hostname']) if cust_options.has_key?('hostname')
+            cust_global_ip_settings.dnsSuffixList = cust_options['dnsSuffixList'] || [cust_domain]
+            cust_hostname = RbVmomi::VIM::CustomizationFixedName.new(:name => cust_options['hostname']) if cust_options.key?('hostname')
             cust_hostname ||= RbVmomi::VIM::CustomizationFixedName.new(:name => options['name'])
             cust_hwclockutc = cust_options['hw_clock_utc']
             cust_timezone = cust_options['time_zone']
@@ -233,7 +247,7 @@ module Fog
           clone_spec = RbVmomi::VIM.VirtualMachineCloneSpec(:location => relocation_spec,
                                                             :config => virtual_machine_config_spec,
                                                             :customization => customization_spec,
-                                                            :powerOn  => options.has_key?('power_on') ? options['power_on'] : true,
+                                                            :powerOn  => options.key?('power_on') ? options['power_on'] : true,
                                                             :template => false)
 
           # Perform the actual Clone Task
@@ -245,7 +259,7 @@ module Fog
           # to set 'wait' => true if your app wants to wait.  Otherwise, you're
           # going to have to reload the server model over and over which
           # generates a lot of time consuming API calls to vmware.
-          if options['wait'] then
+          if options.fetch('wait', true) then
             # REVISIT: It would be awesome to call a block passed to this
             # request to notify the application how far along in the process we
             # are.  I'm thinking of updating a progress bar, etc...
@@ -254,7 +268,7 @@ module Fog
             tries = 0
             new_vm = begin
               # Try and find the new VM (folder.find is quite efficient)
-              folder.find(options['name'], RbVmomi::VIM::VirtualMachine) or raise Fog::Vsphere::Errors::NotFound
+              dest_folder.find(options['name'], RbVmomi::VIM::VirtualMachine) or raise Fog::Vsphere::Errors::NotFound
             rescue Fog::Vsphere::Errors::NotFound
               tries += 1
               if tries <= 10 then
@@ -268,11 +282,10 @@ module Fog
           # Return hash
           {
             'vm_ref'        => new_vm ? new_vm._ref : nil,
-            'new_vm'        => new_vm ? get_virtual_machine("#{options['dest_folder']}/#{options['name']}", options['datacenter']) : nil,
+            'new_vm'        => new_vm ? convert_vm_mob_ref_to_attr_hash(new_vm) : nil,
             'task_ref'      => task._ref
           }
         end
-
       end
 
       class Mock
@@ -301,7 +314,6 @@ module Fog
             'task_ref' => "task-#{Fog::Mock.random_numbers(4)}",
           }
         end
-
       end
     end
   end
